Functions
- generate_
hooks - to_path: Is the directory in which files should be written to. When
None, defaults toOUT_DIRprost_mod: If you moved the codegen of proto in a module
None, defaults to OUT_DIRprost_mod: If you moved the codegen of proto in a module